/*
 * This software is the confidential and proprietary information of
 * Smardec. You shall not disclose or distribute such Confidential Information.
 * This software shall not be integrated, copied (partially or fully),
 * or reverse engineered into any other software, program, or code that is
 * not intended for Smardec. You shall use it only in accordance with the terms
 * of the license agreement you entered into with Smardec.
 *
 * Copyright (C) 2004-2006 Smardec. All rights reserved.
 *
 * http://www.smardec.com
 *
 */

package com.smardec.demo.j2native.demos;

import com.smardec.demo.j2native.Demo;
import com.smardec.demo.j2native.DemoableAdapter;
import com.smardec.demo.j2native.Util;
import com.smardec.demo.j2native.tools.NativeLibraryHelper;

import javax.swing.*;
import javax.swing.border.TitledBorder;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;
import java.awt.*;
import java.util.Vector;

public class WindowsDemo extends DemoableAdapter {
    public final static String CONSTRAINT_WINDOWS = "Windows";
    public final static String CAPTION_WINDOWS = "Windows";
    public final static String URL_SIMPLE = "simple.html";
    public final static String URL_REGISTRY = "registry.html";
    public final static String URL_PLAYER = "player.html";
    public final static String INTRO_WINDOWS = "<html><head>" + css + "</head><body>" +
            "<p align=left color=black>" +
            "<b>Simple Windows API Invocation.</b><br>" +
            "The simpler, the better  this is the motto of the demonstration. What can be simpler and clearer than invocation of such API functions as  MessageBeep() and MessageBox(). And we will start our immersion into J2Native world from these very functions." +
            "<p align=right color=black><a href=" + URL_SIMPLE + ">View Code Sample</a></p>" +
            "<b>Registry Viewer.</b><br>" +
            "This is a more interesting variant of J2Native using. Moreover, it is very useful and used frequently. Registry Viewer, as it is clear from the name, downloads data from Windows registry. (NOTE: program works in Read-Only mode. No changes will be made under any circumstances.) In general almost every program needs work with registry and Java application is no exception to that. As examples of registry use the following variants may be used: the registration of data types, the storage of configuration setting for program operation and of its launch keys and, certainly, the storage of registration information. But this is not the end, the registry itself is a whole database containing of useful and necessary information about the system and its settings. Thus, it becomes clear that to deprive Java application of access to the registry would be a great mistake. And though Java does not hold such possibilities in itself, making use of J2Native you will have Windows registry in your possession." +
            "<p align=right color=black><a href=" + URL_REGISTRY + ">View Code Sample</a></p>" +
            "<b>CD Player.</b><br>" +
            "As a software creator you must have had a thought that Java, though being an extremely high-end and flexible platform, is terribly limited in its possibilities. For example, Java is not able to create beautiful windows of various shape and configuration and as a result you have to put up with this rectangle design which is geometrically absolutely rectilinear.  And you want to make something beautiful and unusual, something original and astonishing, something which is different from what others have. Or another example is system tray. It would be great if Java could work with it.  And the most important thing is work with equipment. Java does not have such an option. It is good from the point of view of security but when such a necessity arises there is no place for abstract theories left and you have to reject Java and choose something else which is native, for instance C++ or even Assembler. The worst variant is that when one part of the application is written in Java and the other part is in another native language, and interaction between them is realized by means of JNI. The maintenance and support of such a program turn out to be absolute hell for programmers and take a lot of time to provide integrity and correctness of JNI interaction. And we do not mention about the loss of time on switching from Java into a native language and then back into Java and then again to the native language and so on and so forth. This is not a nightmare but actual work of a programmer who does not know about the existence of J2Native library. Everything described above and a lot of other things can be made in Java using J2Native because it was worked out for these very purposes. And CD Player demo program exists to confirm our words. If you want your own window, here it is. If you need system tray, consider you have it.  If you need access to equipment, there is no problem; it is in your hands and under your control." +
            "<p align=right color=black><a href=" + URL_PLAYER + ">View Code Sample</a></p>" +
            "</p>" +
            "</body></html>";

    private JPanel jPanelOptions = null;
    private JPanel jPanelDesc = null;

    public String getID() {
        return CONSTRAINT_WINDOWS;
    }

    public String getCaption() {
        return CAPTION_WINDOWS;
    }

    public Vector getContentDescriptions() {
        return null;
    }

    public int getState() {
        return STATE_NONE;
    }

    public JPanel getDemoPanel() {
        JPanel jPanelContents = new JPanel(new GridBagLayout());
        TitledBorder titledBorder = BorderFactory.createTitledBorder(CAPTION_WINDOWS);
        titledBorder.setTitleColor(Color.black);
        jPanelContents.setBorder(titledBorder);
        JEditorPane jEditorPane = new JEditorPane("text/html", INTRO_WINDOWS);
        jEditorPane.setEditable(false);
        jEditorPane.setCaretPosition(0);
        jEditorPane.setBackground(jPanelContents.getBackground());
        jEditorPane.addHyperlinkListener(new HyperlinkListener() {
            public void hyperlinkUpdate(HyperlinkEvent e) {
                if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
                    showSourceDialog(e.getDescription());
                }
            }
        });
        Util.constrain(jPanelContents, new JScrollPane(jEditorPane),
                0, 0, 1, 1, GridBagConstraints.BOTH, GridBagConstraints.NORTHWEST, 1, 1,
                0, 5, 0, 5);

        return jPanelContents;
    }

    public JPanel getOptionPanel() {
        if (jPanelOptions != null)
            return jPanelOptions;
        return null;
    }

    public JPanel getDescriptionPanel() {
        if (jPanelDesc != null)
            return jPanelDesc;
        return null;
    }

    public void init(Component parentFrame) {
        NativeLibraryHelper.getInstance();
    }

    public void deinit() {
        NativeLibraryHelper.getInstance().reset();
    }

    private void showSourceDialog(String url) {
        final Demo instance = Demo.getInstance();
        if (URL_SIMPLE.equals(url)) {
            instance.setActiveDemo(WinSimpleDemo.CONSTRAINT_WIN_SIMPLE);
            instance.showSrcPanel(50);
        } else if (URL_REGISTRY.equals(url)) {
            instance.setActiveDemo(WinRegistryDemo.CONSTRAINT_WIN_REGISTRY);
            instance.showSrcPanel(50);
        } else if (URL_PLAYER.equals(url)) {
            instance.setActiveDemo(WinPlayerDemo.CONSTRAINT_WIN_PLAYER);
            instance.showSrcPanel(50);
        }
    }
}

